EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Assets_CreateOrUpdateItem',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ NULL,
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'AssetItem_Id',
    /* Description_Text        */ 'Creates or updates the specified asset.'
GO

IF OBJECT_ID('[Assets_CreateOrUpdateItem]') IS NOT NULL DROP PROCEDURE [Assets_CreateOrUpdateItem]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Assets_CreateOrUpdateItem]
(
	@Feed_Id INT,
	@AssetItem_Name NVARCHAR(200),
	@Parent_AssetItem_Id INT,
	@AssetItem_Size BIGINT,
	@ContentType_Text VARCHAR(200),
	@SHA1Hash_Bytes BINARY(20),
	@Modified_Date DATETIME,
	@Created_Date DATETIME,
	@Directory_Indicator YNINDICATOR,
	@AssetItem_Id INT = NULL OUT
)
AS
BEGIN

	SET NOCOUNT ON

    IF @AssetItem_Id IS NULL
    BEGIN

		INSERT INTO [AssetItems]
		(
			[Feed_Id],
			[Parent_AssetItem_Id],
			[AssetItem_Name],
			[AssetItem_Size],
			[ContentType_Text],
			[SHA1Hash_Bytes],
			[Download_Count],
			[Modified_Date],
			[Created_Date],
			[Directory_Indicator]
		)
		VALUES
		(
			@Feed_Id,
			@Parent_AssetItem_Id,
			@AssetItem_Name,
			@AssetItem_Size,
			@ContentType_Text,
			@SHA1Hash_Bytes,
			0,
			COALESCE(@Modified_Date, GETUTCDATE()),
			COALESCE(@Created_Date, GETUTCDATE()),
			@Directory_Indicator
		)

		SET @AssetItem_Id = SCOPE_IDENTITY()
      
    END
    ELSE
    BEGIN

	    UPDATE [AssetItems]
           SET [AssetItem_Name] = COALESCE(@AssetItem_Name, [AssetItem_Name]),
		       [Parent_AssetItem_Id] = COALESCE(@Parent_AssetItem_Id, [Parent_AssetItem_Id]),
			   [AssetItem_Size] = COALESCE(@AssetItem_Size, [AssetItem_Size]),
			   [ContentType_Text] = NULLIF(COALESCE(@ContentType_Text, [ContentType_Text]), ''),
			   [SHA1Hash_Bytes] = COALESCE(@SHA1Hash_Bytes, [SHA1Hash_Bytes]),
			   [Modified_Date] = COALESCE(@Modified_Date, [Modified_Date]),
			   [Created_Date] = COALESCE(@Created_Date, [Created_Date]),
			   [Directory_Indicator] = COALESCE(@Directory_Indicator, [Directory_Indicator])
         WHERE [AssetItem_Id] = @AssetItem_Id

     END

END
GO

GRANT EXECUTE ON [Assets_CreateOrUpdateItem] TO [ProGetUser_Role]