EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Feeds_UpdateSyncSettings',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Updates sync settings for a feed.'
GO

IF OBJECT_ID('[Feeds_UpdateSyncSettings]') IS NOT NULL
	DROP PROCEDURE [Feeds_UpdateSyncSettings]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Feeds_UpdateSyncSettings]
(
	@Feed_Id INT,
	@Sync_Url VARCHAR(250) = NULL,
	@RemoteFeed_Name NVARCHAR(250) = NULL,
	@RemoteFeed_APIKey_Bytes VARBINARY(250),
	@Sync_Frequency_Minutes INT,
	@Active_Indicator YNINDICATOR
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT * FROM [NuGetSyncFeeds] WITH (UPDLOCK) WHERE [Feed_Id] = @Feed_Id)
	BEGIN

		UPDATE [NuGetSyncFeeds]
		   SET [Sync_Url] = @Sync_Url,
		       [RemoteFeed_Name] = @RemoteFeed_Name,
			   [RemoteFeed_APIKey_Bytes] = @RemoteFeed_APIKey_Bytes,
			   [Sync_Frequency_Minutes] = @Sync_Frequency_Minutes,
			   [Active_Indicator] = @Active_Indicator
		 WHERE [Feed_Id] = @Feed_Id

	END
	ELSE
	BEGIN

		IF (SELECT [FeedType_Name] FROM [Feeds] WHERE [Feed_Id] = @Feed_Id) NOT IN ('NuGet', 'Chocolatey', 'PowerShell')
			RAISERROR('Feed type must be NuGet, Chocolatey, or PowerShell to use NuGet feed sync.', 16, 1)

		INSERT INTO [NuGetSyncFeeds]
		(
			[Feed_Id],
			[Sync_Url],
			[RemoteFeed_Name],
			[RemoteFeed_APIKey_Bytes],
			[Sync_Frequency_Minutes],
			[Active_Indicator],
			[Last_Sync_Date]
		)
		VALUES
		(
			@Feed_Id,
			@Sync_Url,
			@RemoteFeed_Name,
			@RemoteFeed_APIKey_Bytes,
			@Sync_Frequency_Minutes,
			@Active_Indicator,
			NULL
		)

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Feeds_UpdateSyncSettings] TO [ProGetUser_Role]
GO