EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'IndexingServers_SetUpdated',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Primary_Indicator',
    /* Description_Text        */ 'Sets the last updated date for an indexing server.'
GO

IF OBJECT_ID('[IndexingServers_SetUpdated]') IS NOT NULL
	DROP PROCEDURE [IndexingServers_SetUpdated]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [IndexingServers_SetUpdated]
(
	@Server_Name NVARCHAR(64),
	@IPAddress_Text VARCHAR(100),
	@Primary_Indicator YNINDICATOR = NULL OUT
)
AS
BEGIN
SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @Now DATETIME
	SET @Now = GETUTCDATE()

	DECLARE @FailOver_Minutes INT
	SET @FailOver_Minutes = COALESCE((SELECT [Value_Text]
	                                    FROM [Configuration]
							           WHERE [Key_Name] = 'Service.FailoverPeriod'), 5)

	DECLARE @Minimum_Date DATETIME
	SET @Minimum_Date = DATEADD(MINUTE, @FailOver_Minutes * -1, @Now)

	SET @Primary_Indicator = (SELECT [Primary_Indicator]
	                            FROM [IndexingServers]
							   WHERE [Server_Name] = @Server_Name)

	IF @Primary_Indicator IS NOT NULL
	BEGIN

		UPDATE [IndexingServers]
		   SET [LastUpdated_Date] = @Now
		 WHERE [Server_Name] = @Server_Name

	END
	ELSE
	BEGIN

		INSERT INTO [IndexingServers]
		(
			[Server_Name],
			[IPAddress_Text],
			[LastUpdated_Date],
			[Primary_Indicator]
		)
		VALUES
		(
			@Server_Name,
			@IPAddress_Text,
			@Now,
			'N'
		)

		SET @Primary_Indicator = 'N'

	END

	UPDATE [IndexingServers]
	  WITH (TABLOCK)
	   SET [Primary_Indicator] = 'N'
	 WHERE [Primary_Indicator] = 'Y'
	   AND [LastUpdated_Date] < @Minimum_Date

	IF NOT EXISTS(SELECT * FROM [IndexingServers] WITH (TABLOCK) WHERE [Primary_Indicator] = 'Y')
	BEGIN

		UPDATE [IndexingServers]
		  WITH (TABLOCK)
		   SET [Primary_Indicator] = 'Y'
		 WHERE [Server_Name] = @Server_Name

	    SET @Primary_Indicator = 'Y'

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [IndexingServers_SetUpdated] TO [ProGetUser_Role]
GO
